@@ -5,8 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 1.3
-;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4"))
+;; Version: 1.4
+;; Package-Requires: ((emacs "27.1") (compat "30"))
 ;; Homepage: https://github.com/minad/org-modern
 ;; Keywords: outlines, hypermedia, text
 
@@ -481,9 +481,8 @@ the font.")
      (if-let ((face (or (cdr (assoc todo org-modern-todo-faces))
                         (cdr (assq t org-modern-todo-faces)))))
          `(:inherit (,face org-modern-label))
-       (if (member todo org-done-keywords)
-           'org-modern-done
-         'org-modern-todo)))))
+       (if (string-match-p org-not-done-regexp todo)
+           'org-modern-todo 'org-modern-done)))))
 
 (defun org-modern--timestamp ()
   "Prettify timestamps."
@@ -661,8 +660,12 @@ whole buffer; otherwise, for the line at point."
     (unless (equal (and (listp box) (plist-get box :color))
                    (face-attribute 'default :background nil t))
       (org-modern--update-label-face)))
-  (setf org-modern--table-sp-width (default-font-width)
-        (cadr org-modern--table-overline) (face-attribute 'org-table :foreground nil t)))
+  (let ((face-remapping-alist
+         (if-let ((d (ensure-list (cdr (assq 'default face-remapping-alist)))))
+             `((default org-table ,@d default))
+           '((default org-table default)))))
+    (setq org-modern--table-sp-width (default-font-width)))
+  (setf (cadr org-modern--table-overline) (face-attribute 'org-table :foreground nil t)))
 
 (defun org-modern--update-label-face ()
   "Update border of the `org-modern-label' face."
@@ -681,7 +684,7 @@ whole buffer; otherwise, for the line at point."
        (list :color (face-attribute 'default :background nil t)
              :line-width
              ;; Emacs 28 supports different line horizontal and vertical line widths
-             (if (eval-when-compile (>= emacs-major-version 28))
+             (static-if (>= emacs-major-version 28)
                  (cons -1 (- border))
                (- border)))))))
 
@@ -766,12 +769,6 @@ whole buffer; otherwise, for the line at point."
            (3 '(face nil display ,(org-modern--symbol (caddr org-modern-radio-target))))
            ,@(unless (cadr org-modern-radio-target)
                '((2 '(face nil invisible org-modern)))))))))
-   (when org-modern-timestamp
-     '(("\\(?:<\\|\\[\\)\\([0-9]\\{4\\}-[0-9]\\{2\\}-[0-9]\\{2\\}\\(?: [[:word:]]+\\.?\\)?\\(?: [.+-]+[0-9ymwdh/]+\\)*\\)\\(\\(?: [0-9:-]+\\)?\\(?: [.+-]+[0-9ymwdh/]+\\)*\\)\\(?:>\\|\\]\\)"
-        (0 (org-modern--timestamp)))
-       ("<[^>]+>\\(-\\)\\(-\\)<[^>]+>\\|\\[[^]]+\\]\\(?1:-\\)\\(?2:-\\)\\[[^]]+\\]"
-        (1 '(face org-modern-label display #("  " 1 2 (face (:strike-through t) cursor t))) t)
-        (2 '(face org-modern-label display #("  " 0 1 (face (:strike-through t)))) t))))
    (when (integerp org-modern-progress)
      `((" \\(\\[\\(?:\\([0-9]+\\)%\\|\\([0-9]+\\)/\\([0-9]+\\)\\)]\\)"
         (0 (org-modern--progress)))))
@@ -792,6 +789,12 @@ whole buffer; otherwise, for the line at point."
             ('t '(1 '(face nil invisible org-modern)))
             ((pred stringp) `(1 '(face nil display ,org-modern-keyword)))
             (_ '(0 (org-modern--keyword)))))))
+   (when org-modern-timestamp
+     '(("\\(?:<\\|\\[\\)\\([0-9]\\{4\\}-[0-9]\\{2\\}-[0-9]\\{2\\}\\(?: [[:word:]]+\\.?\\)?\\(?: [.+-]+[0-9ymwdh/]+\\)*\\)\\(\\(?: [0-9:-]+\\)?\\(?: [.+-]+[0-9ymwdh/]+\\)*\\)\\(?:>\\|\\]\\)"
+        (0 (org-modern--timestamp)))
+       ("<[^>]+>\\(-\\)\\(-\\)<[^>]+>\\|\\[[^]]+\\]\\(?1:-\\)\\(?2:-\\)\\[[^]]+\\]"
+        (1 '(face org-modern-label display #("  " 1 2 (face (:strike-through t) cursor t))) t)
+        (2 '(face org-modern-label display #("  " 0 1 (face (:strike-through t)))) t))))
    ;; Do not add source block fringe markers if org-indent-mode is
    ;; enabled. org-indent-mode uses line prefixes for indentation.
    ;; Therefore we cannot have both.
@@ -898,13 +901,14 @@ whole buffer; otherwise, for the line at point."
       (let (case-fold-search)
         (when org-modern-todo
           (goto-char (point-min))
-          (let ((re (format " %s "
-                            (regexp-opt
-                             (append org-todo-keywords-for-agenda
-                                     org-done-keywords-for-agenda) t)))
-                (org-done-keywords org-done-keywords-for-agenda))
-            (while (re-search-forward re nil 'noerror)
-              (org-modern--todo))))
+          (while (< (point) (point-max))
+            (when-let (((get-text-property (point) 'todo-state))
+                       (org-not-done-regexp (get-text-property (point) 'org-not-done-regexp))
+                       (re (get-text-property (point) 'org-todo-regexp))
+                       (re (concat " " re " "))
+                       ((re-search-forward re (pos-eol) 'noerror)))
+              (org-modern--todo))
+            (goto-char (min (1+ (pos-eol)) (point-max)))))
         (when org-modern-tag
           (goto-char (point-min))
           (let ((re (concat "\\( \\)\\(:\\(?:" org-tag-re "::?\\)+\\)[ \t]*$")))
